//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Files/DatafilesSet.h
//! @brief     Defines class DatafilesSet.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_FILES_DATAFILESSET_H
#define BORNAGAIN_GUI_MODEL_FILES_DATAFILESSET_H

#include "Base/Types/VectorWC.h"
#include "GUI/Model/Files/DatafilesCleaner.h"
#include <QObject>
#include <QXmlStreamWriter>

class DataItem;
class DatafileItem;
class MessageService;

//! The DatafilesSet class is a model to store all imported DatafileItem's.
class DatafilesSet : public QObject, public VectorWC<DatafileItem> {
    Q_OBJECT
public:
    explicit DatafilesSet();
    ~DatafilesSet();

    void readFrom(QXmlStreamReader* r);
    void readDatafiles(const QString& projectDir, MessageService* messageService);

    QStringList realItemNames() const;
    void writeTo(QXmlStreamWriter* w) const;
    void writeDatafiles(const QString& projectDir) const;

private:
    QVector<DataItem*> dataItems() const;

    mutable DatafilesCleaner dataFilesCleaner;
};

#endif // BORNAGAIN_GUI_MODEL_FILES_DATAFILESSET_H
