//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/List/InstrumentsQListView.cpp
//! @brief     Implements class InstrumentsQListView.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/List/InstrumentsQListView.h"
#include "GUI/Model/Device/InstrumentsSet.h"
#include "GUI/Model/Project/ProjectDocument.h"
#include "GUI/View/List/InstrumentsQModel.h"
#include "GUI/View/Widget/ListItemDelegate.h"

InstrumentsQListView::InstrumentsQListView(InstrumentsQModel* model)
{
    setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
    setMovement(QListView::Static);
    setSelectionMode(QAbstractItemView::NoSelection);

    setModel(model);
    setItemDelegate(new ListItemDelegate(this));

    connect(this, &QListView::clicked, [](const QModelIndex& qi) {
        gDoc->instrumentsModifier()->setCurrentIndex(qi.row());
        emit gDoc->instruments()->setChanged();
    });

    disconnect(gDoc->instruments(), &InstrumentsSet::setChanged, nullptr, nullptr);
    connect(gDoc->instruments(), &InstrumentsSet::setChanged, [this, model] {
        setCurrentIndex(model->index(gDoc->instruments()->currentIndex(), 0));
        repaint();
    });

    setContextMenuPolicy(Qt::ActionsContextMenu);
}
