//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Loader/ComponentRW.cpp
//! @brief     Implements class PythonScriptWidget.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Loader/ComponentRW.h"
#include "GUI/Model/Device/InstrumentItems.h"
#include "GUI/Model/Device/InstrumentXML.h"
#include "GUI/View/Layout/ApplicationSettings.h"
#include "GUI/View/Widget/FileDialog.h"
#include <QMessageBox>

namespace {

template <class T> void save(const QString& fname, const T* t);
template <class T> T* load(const QString& fname);

template <> void save<InstrumentItem>(const QString& fname, const InstrumentItem* t)
{
    InstrumentXML::save(fname, t);
}
template <> InstrumentItem* load<InstrumentItem>(const QString& fname)
{
    return InstrumentXML::load(fname);
}

} // namespace


// Force instantiation by assigning the function to a global variable that will never be used:
auto dummy_saveComponent_InstrumentItem = &RW::saveComponent<class InstrumentItem>;
auto dummy_loadComponent_InstrumentItem = &RW::loadComponent<class InstrumentItem>;

template <class T> void RW::saveComponent(const QString& type, const T* t)
{
    if (!t)
        return;

    QString fname = GUI::Dialog::fileSaveDialog("Save " + type, appSettings->xml_dir,
                                                "XML Files (*.xml)", t->name() + ".xml");
    if (fname.isEmpty())
        return;

    try {
        ::save<T>(fname, t);
    } catch (const std::exception& ex) {
        QMessageBox(QMessageBox::Warning, "BornAgain: failed saving", ex.what(), QMessageBox::Ok,
                    nullptr)
            .exec();
    }
}

template <class T> T* RW::loadComponent(const QString& type)
{
    QString fname =
        GUI::Dialog::fileOpenDialog("Load " + type, appSettings->xml_dir, "XML Files (*.xml)");
    if (fname.isEmpty())
        return nullptr;

    try {
        return ::load<T>(fname);
    } catch (const std::exception& ex) {
        QMessageBox(QMessageBox::Warning, "BornAgain: failed loading", ex.what(), QMessageBox::Ok,
                    nullptr)
            .exec();
    }
    return nullptr;
}
